<?php
/**
 * Initialize the options before anything else.
 */
add_action( 'admin_init', 'custom_theme_options', 1 );

/**
 * Build the custom settings & update OptionTree.
 */
function custom_theme_options() {
  /**
   * Get a copy of the saved settings array. 
   */
  $saved_settings = get_option( 'option_tree_settings', array() );
  
  /**
   * Custom settings array that will eventually be 
   * passes to the OptionTree Settings API Class.
   */
  $custom_settings = array( 
    'contextual_help' => array( 
      'sidebar'       => ''
    ),
    'sections'        => array( 
      array(
        'id'          => 'general_section',
        'title'       => 'General settings'
      ),
      array(
        'id'          => 'fonts_settings_section',
        'title'       => 'Fonts settings'
      ),
      array(
        'id'          => 'header_settings_section',
        'title'       => 'Header settings'
      ),
      array(
        'id'          => 'style_navigation_section',
        'title'       => 'Navigation settings'
      ),
      array(
        'id'          => 'style_content_section',
        'title'       => 'Content settings'
      ),
      array(
        'id'          => 'style_boxes_section',
        'title'       => 'Column settings'
      ),
      array(
        'id'          => 'style_footer_section',
        'title'       => 'Footer settings'
      ),
      array(
        'id'          => 'social_section',
        'title'       => 'Social media settings'
      ),
      array(
        'id'          => 'ads_section',
        'title'       => 'Advertisement settings'
      ),
    ),
    'settings'        => array( 
      array(
        'id'          => 'general_logo_text',
        'label'       => 'Logo title',
        'desc'        => '',
        'std'         => get_bloginfo('name'),
        'type'        => 'text',
        'section'     => 'general_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
      array(
        'id'          => 'general_logo_descr',
        'label'       => 'Logo Description',
        'desc'        => '',
        'std'         => get_bloginfo('description'),
        'type'        => 'text',
        'section'     => 'general_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
      array(
        'id'          => 'general_logo_img',
        'label'       => 'Logo Image',
        'desc'        => 'It will replace text logo. Height should be max 49px',
        'std'         => '',
        'type'        => 'upload',
        'section'     => 'general_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
      array(
        'id'          => 'general_google_analytics_code',
        'label'       => 'Google Analytics Code',
        'desc'        => 'Place the code you get from google here.',
        'std'         => '',
        'type'        => 'textarea-simple',
        'section'     => 'general_section',
        'rows'        => '4',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
      array(
        'id'          => 'general_footer_text',
        'label'       => 'Footer text',
        'desc'        => 'Use this tags: [stat_post_number]',
        'std'         => 'On this page are [stat_post_number] <b>columns</b></b>.
Lorum ipsum der ti mor fer so bari peror, dor undo ser mi na fa tiros. De mi Lorum ipsum',
        'type'        => 'textarea-simple',
        'section'     => 'general_section',
        'rows'        => '4',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
      array(
        'id'          => 'general_footer_copyrights',
        'label'       => 'Footer Copyrights',
        'desc'        => '',
        'std'         => ' - '.get_bloginfo('description').' (&copy;'.date('Y').') U-columns',
        'type'        => 'text',
        'section'     => 'general_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
      array(
        'id'          => 'general_ads_header_1',
        'label'       => 'Header Banner',
        'desc'        => 'Entry the banner code. 468x60',
        'std'         => '<a href="#"><img src="'.get_template_directory_uri().'/images/pic_c_1.png" alt=""></a>',
        'type'        => 'textarea-simple',
        'section'     => 'ads_section',
        'rows'        => '4',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
      array(
        'id'          => 'style_hearder_option',
        'label'       => 'Header options',
        'desc'        => '',
        'std'         => '',
        'type'        => 'textblock-titled',
        'section'     => 'header_settings_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
      array(
        'id'          => 'style_header_height',
        'label'       => 'Header height',
        'desc'        => 'Select a height in px.',
        'std'         => '77',
        'type'        => 'text',
        'section'     => 'header_settings_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
      array(
        'id'          => 'style_header_bg_img',
        'label'       => 'Background options',
        'desc'        => '',
        'std'         => '',
        'type'        => 'background',
        'section'     => 'header_settings_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
      array(
        'id'          => 'style_header_bg_img_100percent',
        'label'       => 'Full width background Image',
        'desc'        => '',
        'std'         => '',
        'type'        => 'checkbox',
        'section'     => 'header_settings_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'choices'     => array( 
          array(
            'value'       => 'yes',
            'label'       => 'Enable 100% background cover',
            'src'         => ''
          )
        ),
      ),
      array(
        'id'          => 'style_logo_pos',
        'label'       => 'Header Logo position',
        'desc'        => '',
        'std'         => 'menu',
        'type'        => 'select',
        'section'     => 'header_settings_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'choices'     => array( 
          array(
            'value'       => 'menu',
            'label'       => 'Menu',
            'src'         => ''
          ),
          array(
            'value'       => 'header',
            'label'       => 'Header',
            'src'         => ''
          )
        ),
      ),
      array(
        'id'          => 'style_logo_text_color',
        'label'       => 'Logo title color',
        'desc'        => 'Select a color.',
        'std'         => '#000000',
        'type'        => 'colorpicker',
        'section'     => 'header_settings_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
      array(
        'id'          => 'style_logo_descr_color',
        'label'       => 'Logo Description Color',
        'desc'        => 'Select a color.',
        'std'         => '#ff5b01',
        'type'        => 'colorpicker',
        'section'     => 'header_settings_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
      array(
        'id'          => 'style_logo_bg_top_color',
        'label'       => 'Logo Background Top gradient color',
        'desc'        => 'Select a color.',
        'std'         => '#ffffff',
        'type'        => 'colorpicker',
        'section'     => 'header_settings_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
      array(
        'id'          => 'style_logo_bg_bottom_color',
        'label'       => 'Logo Background Bottom gradient color',
        'desc'        => 'Select a color.',
        'std'         => '#ededed',
        'type'        => 'colorpicker',
        'section'     => 'header_settings_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
      array(
        'id'          => 'style_search_show',
        'label'       => 'Search bar',
        'desc'        => 'Do you want to show search bar?',
        'std'         => 'yes',
        'type'        => 'radio',
        'section'     => 'header_settings_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'choices'     => array( 
          array(
            'value'       => 'yes',
            'label'       => 'Yes',
            'src'         => ''
          ),
          array(
            'value'       => 'no',
            'label'       => 'No',
            'src'         => ''
          )
        ),
      ),
      array(
        'id'          => 'style_search_position',
        'label'       => 'Search bar position',
        'desc'        => 'Do you want to replace header ads with search box?',
        'std'         => 'no',
        'type'        => 'radio',
        'section'     => 'header_settings_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'choices'     => array( 
          array(
            'value'       => 'yes',
            'label'       => 'Header',
            'src'         => ''
          ),
          array(
            'value'       => 'no',
            'label'       => 'Content',
            'src'         => ''
          )
        ),
      ),
      array(
        'id'          => 'style_date_show',
        'label'       => 'Show Date',
        'desc'        => 'Do you want to show date?',
        'std'         => 'yes',
        'type'        => 'radio',
        'section'     => 'header_settings_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'choices'     => array( 
          array(
            'value'       => 'yes',
            'label'       => 'Yes',
            'src'         => ''
          ),
          array(
            'value'       => 'no',
            'label'       => 'No',
            'src'         => ''
          )
        ),
      ),
      array(
        'id'          => 'style_menu_order',
        'label'       => 'Navigation settings',
        'desc'        => '',
        'std'         => 'below',
        'type'        => 'radio',
        'section'     => 'style_navigation_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'choices'     => array( 
          array(
            'value'       => 'below',
            'label'       => 'Below Header',
            'src'         => ''
          ),
          array(
            'value'       => 'above',
            'label'       => 'Above Header',
            'src'         => ''
          ),
        ),
      ),
      array(
        'id'          => 'style_menu_width',
        'label'       => 'Navigation Width',
        'desc'        => '',
        'std'         => 'full',
        'type'        => 'radio',
        'section'     => 'style_navigation_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'choices'     => array( 
          array(
            'value'       => 'full',
            'label'       => 'Full Width',
            'src'         => ''
          ),
          array(
            'value'       => 'fixed',
            'label'       => 'Fixed',
            'src'         => ''
          )
        ),
      ),
      array(
        'id'          => 'style_menu_show',
        'label'       => 'Show navigation',
        'desc'        => 'Do you want to show navigation bar?',
        'std'         => 'yes',
        'type'        => 'radio',
        'section'     => 'style_navigation_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'choices'     => array( 
          array(
            'value'       => 'yes',
            'label'       => 'Yes',
            'src'         => ''
          ),
          array(
            'value'       => 'no',
            'label'       => 'No',
            'src'         => ''
          )
        ),
      ),
      array(
        'id'          => 'style_menu_top_margin',
        'label'       => 'Top Margin',
        'desc'        => ' in px.',
        'std'         => '0',
        'type'        => 'text',
        'section'     => 'style_navigation_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
      array(
        'id'          => 'style_menu_bottom_margin',
        'label'       => 'Bottom Margin',
        'desc'        => ' in px.',
        'std'         => '0',
        'type'        => 'text',
        'section'     => 'style_navigation_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
      array(
        'id'          => 'style_menu_top_border_width',
        'label'       => 'Top Border Width',
        'desc'        => 'Select a width.',
        'std'         => '0',
        'type'        => 'select',
        'section'     => 'style_navigation_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'choices'     => array( 
          array(
            'value'       => '0',
            'label'       => '0',
            'src'         => ''
          ),
          array(
            'value'       => '1',
            'label'       => '1',
            'src'         => ''
          ),
          array(
            'value'       => '2',
            'label'       => '2',
            'src'         => ''
          ),
          array(
            'value'       => '3',
            'label'       => '3',
            'src'         => ''
          ),
          array(
            'value'       => '4',
            'label'       => '4',
            'src'         => ''
          ),
          array(
            'value'       => '5',
            'label'       => '5',
            'src'         => ''
          ),
        ),
      ),
      array(
        'id'          => 'style_menu_top_border_style',
        'label'       => 'Top Border Style',
        'desc'        => 'Select a style.',
        'std'         => 'solid',
        'type'        => 'select',
        'section'     => 'style_navigation_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'choices'     => array( 
          array(
            'value'       => 'dotted',
            'label'       => 'dotted',
            'src'         => ''
          ),
          array(
            'value'       => 'dashed',
            'label'       => 'dashed',
            'src'         => ''
          ),
          array(
            'value'       => 'solid',
            'label'       => 'solid',
            'src'         => ''
          ),
          array(
            'value'       => 'double',
            'label'       => 'double',
            'src'         => ''
          ),
          array(
            'value'       => 'groove',
            'label'       => 'groove',
            'src'         => ''
          ),
          array(
            'value'       => 'ridge',
            'label'       => 'ridge',
            'src'         => ''
          ),
          array(
            'value'       => 'inset',
            'label'       => 'inset',
            'src'         => ''
          ),
          array(
            'value'       => 'outset',
            'label'       => 'outset',
            'src'         => ''
          ),
        ),
      ),
      array(
        'id'          => 'style_menu_top_border_color',
        'label'       => 'Top Border Color',
        'desc'        => 'Select a color.',
        'std'         => '#000000',
        'type'        => 'colorpicker',
        'section'     => 'style_navigation_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
      array(
        'id'          => 'style_menu_bottom_border_width',
        'label'       => 'Bottom Border Width',
        'desc'        => 'Select a width.',
        'std'         => '0',
        'type'        => 'select',
        'section'     => 'style_navigation_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'choices'     => array( 
          array(
            'value'       => '0',
            'label'       => '0',
            'src'         => ''
          ),
          array(
            'value'       => '1',
            'label'       => '1',
            'src'         => ''
          ),
          array(
            'value'       => '2',
            'label'       => '2',
            'src'         => ''
          ),
          array(
            'value'       => '3',
            'label'       => '3',
            'src'         => ''
          ),
          array(
            'value'       => '4',
            'label'       => '4',
            'src'         => ''
          ),
          array(
            'value'       => '5',
            'label'       => '5',
            'src'         => ''
          ),
        ),
      ),
      array(
        'id'          => 'style_menu_bottom_border_style',
        'label'       => 'Bottom Border Style',
        'desc'        => 'Select a style.',
        'std'         => 'solid',
        'type'        => 'select',
        'section'     => 'style_navigation_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'choices'     => array( 
          array(
            'value'       => 'dotted',
            'label'       => 'dotted',
            'src'         => ''
          ),
          array(
            'value'       => 'dashed',
            'label'       => 'dashed',
            'src'         => ''
          ),
          array(
            'value'       => 'solid',
            'label'       => 'solid',
            'src'         => ''
          ),
          array(
            'value'       => 'double',
            'label'       => 'double',
            'src'         => ''
          ),
          array(
            'value'       => 'groove',
            'label'       => 'groove',
            'src'         => ''
          ),
          array(
            'value'       => 'ridge',
            'label'       => 'ridge',
            'src'         => ''
          ),
          array(
            'value'       => 'inset',
            'label'       => 'inset',
            'src'         => ''
          ),
          array(
            'value'       => 'outset',
            'label'       => 'outset',
            'src'         => ''
          ),
        ),
      ),
      array(
        'id'          => 'style_menu_bottom_border_color',
        'label'       => 'Bottom Border Color',
        'desc'        => 'Select a color.',
        'std'         => '#000000',
        'type'        => 'colorpicker',
        'section'     => 'style_navigation_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
      array(
        'id'          => 'style_menu_link_border_width',
        'label'       => 'Navigation button Border Width',
        'desc'        => 'Select a width.',
        'std'         => '0',
        'type'        => 'select',
        'section'     => 'style_navigation_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'choices'     => array( 
          array(
            'value'       => '0',
            'label'       => '0',
            'src'         => ''
          ),
          array(
            'value'       => '1',
            'label'       => '1',
            'src'         => ''
          ),
          array(
            'value'       => '2',
            'label'       => '2',
            'src'         => ''
          ),
          array(
            'value'       => '3',
            'label'       => '3',
            'src'         => ''
          ),
          array(
            'value'       => '4',
            'label'       => '4',
            'src'         => ''
          ),
          array(
            'value'       => '5',
            'label'       => '5',
            'src'         => ''
          ),
        ),
      ),
      array(
        'id'          => 'style_menu_link_border_radius',
        'label'       => 'Navigation button radius',
        'desc'        => 'Select a radius.',
        'std'         => '0',
        'type'        => 'select',
        'section'     => 'style_navigation_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'choices'     => array( 
          array(
            'value'       => '0',
            'label'       => '0',
            'src'         => ''
          ),
          array(
            'value'       => '1',
            'label'       => '1',
            'src'         => ''
          ),
          array(
            'value'       => '2',
            'label'       => '2',
            'src'         => ''
          ),
          array(
            'value'       => '3',
            'label'       => '3',
            'src'         => ''
          ),
          array(
            'value'       => '4',
            'label'       => '4',
            'src'         => ''
          ),
          array(
            'value'       => '5',
            'label'       => '5',
            'src'         => ''
          ),
        ),
      ),
      array(
        'id'          => 'style_menu_link_border_style',
        'label'       => 'Navigation button Style',
        'desc'        => 'Select a style.',
        'std'         => 'solid',
        'type'        => 'select',
        'section'     => 'style_navigation_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'choices'     => array( 
          array(
            'value'       => 'dotted',
            'label'       => 'dotted',
            'src'         => ''
          ),
          array(
            'value'       => 'dashed',
            'label'       => 'dashed',
            'src'         => ''
          ),
          array(
            'value'       => 'solid',
            'label'       => 'solid',
            'src'         => ''
          ),
          array(
            'value'       => 'double',
            'label'       => 'double',
            'src'         => ''
          ),
          array(
            'value'       => 'groove',
            'label'       => 'groove',
            'src'         => ''
          ),
          array(
            'value'       => 'ridge',
            'label'       => 'ridge',
            'src'         => ''
          ),
          array(
            'value'       => 'inset',
            'label'       => 'inset',
            'src'         => ''
          ),
          array(
            'value'       => 'outset',
            'label'       => 'outset',
            'src'         => ''
          ),
        ),
      ),
      array(
        'id'          => 'style_menu_link_border_color',
        'label'       => 'Navigation button Border Color',
        'desc'        => 'Select a color.',
        'std'         => '#000000',
        'type'        => 'colorpicker',
        'section'     => 'style_navigation_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
      array(
        'id'          => 'style_menu_link_color',
        'label'       => 'Navigation Link Color',
        'desc'        => 'Select a color.',
        'std'         => '#000000',
        'type'        => 'colorpicker',
        'section'     => 'style_navigation_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
      array(
        'id'          => 'style_menu_hover_link_color',
        'label'       => 'Navigation Hover Link Color',
        'desc'        => 'Select a color.',
        'std'         => '#ffffff',
        'type'        => 'colorpicker',
        'section'     => 'style_navigation_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
      array(
        'id'          => 'style_menu_hover_bg_top_color',
        'label'       => 'Navigation button gradient Top Color',
        'desc'        => 'Select a color.',
        'std'         => '#fca275',
        'type'        => 'colorpicker',
        'section'     => 'style_navigation_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
      array(
        'id'          => 'style_menu_hover_bg_bottom_color',
        'label'       => 'Navigation button gradient Bottom Color',
        'desc'        => 'Select a color.',
        'std'         => '#e94d00',
        'type'        => 'colorpicker',
        'section'     => 'style_navigation_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
      array(
        'id'          => 'style_menu_shadow_show',
        'label'       => 'Show Navigation bar Shadow',
        'desc'        => 'Do you want to show a shadow below the navigation?',
        'std'         => 'yes',
        'type'        => 'radio',
        'section'     => 'style_navigation_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'choices'     => array( 
          array(
            'value'       => 'yes',
            'label'       => 'Yes',
            'src'         => ''
          ),
          array(
            'value'       => 'no',
            'label'       => 'No',
            'src'         => ''
          )
        ),
      ),
      array(
        'id'          => 'style_menu_line_bg_top_color',
        'label'       => 'Navigation bar gradient Top Color',
        'desc'        => 'Select a color.',
        'std'         => '#ffffff',
        'type'        => 'colorpicker',
        'section'     => 'style_navigation_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
      array(
        'id'          => 'style_menu_line_bg_bottom_color',
        'label'       => 'Navigation bar gradient Bottom Color',
        'desc'        => 'Select a color.',
        'std'         => '#ededed',
        'type'        => 'colorpicker',
        'section'     => 'style_navigation_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
      array(
        'id'          => 'style_menu_bg',
        'label'       => 'Navigation bar background options',
        'desc'        => '',
        'std'         => '',
        'type'        => 'background',
        'section'     => 'style_navigation_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
      array(
        'id'          => 'style_menu_100percent',
        'label'       => 'Full width background Image',
        'desc'        => '',
        'std'         => '',
        'type'        => 'checkbox',
        'section'     => 'style_navigation_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'choices'     => array( 
          array(
            'value'       => 'yes',
            'label'       => 'Enable 100% background cover',
            'src'         => ''
          )
        ),
      ),
      array(
        'id'          => 'style_menu_hide_all_bg',
        'label'       => 'Hide Background',
        'desc'        => '',
        'std'         => '',
        'type'        => 'checkbox',
        'section'     => 'style_navigation_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'choices'     => array( 
          array(
            'value'       => 'yes',
            'label'       => 'Do you want to hide background image and color?',
            'src'         => ''
          )
        ),
      ),
      array(
        'id'          => 'style_menu_separator_color',
        'label'       => 'Navigation Separator Color',
        'desc'        => 'Select a color.',
        'std'         => '#d6d6d6',
        'type'        => 'colorpicker',
        'section'     => 'style_navigation_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
      array(
        'id'          => 'style_bg_box_search_color',
        'label'       => 'Background Search bar Color',
        'desc'        => 'Select a color.',
        'std'         => '#ffffff',
        'type'        => 'colorpicker',
        'section'     => 'style_content_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
      array(
        'id'          => 'style_bg_box_search_transparent_level',
        'label'       => 'Background Search bar Transparent Level',
        'desc'        => 'Select a level.',
        'std'         => '0.2',
        'type'        => 'select',
        'section'     => 'style_content_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'choices'     => array( 
          array(
            'value'       => '0.1',
            'label'       => '0.1',
            'src'         => ''
          ),
          array(
            'value'       => '0.2',
            'label'       => '0.2',
            'src'         => ''
          ),
          array(
            'value'       => '0.3',
            'label'       => '0.3',
            'src'         => ''
          ),
          array(
            'value'       => '0.4',
            'label'       => '0.4',
            'src'         => ''
          ),
          array(
            'value'       => '0.5',
            'label'       => '0.5',
            'src'         => ''
          ),
          array(
            'value'       => '0.6',
            'label'       => '0.6',
            'src'         => ''
          ),
          array(
            'value'       => '0.7',
            'label'       => '0.7',
            'src'         => ''
          ),
          array(
            'value'       => '0.8',
            'label'       => '0.8',
            'src'         => ''
          ),
          array(
            'value'       => '0.9',
            'label'       => '0.9',
            'src'         => ''
          ),
          array(
            'value'       => '1.0',
            'label'       => '1.0',
            'src'         => ''
          ),
        ),
      ),
      array(
        'id'          => 'style_bg_box_search_text_color',
        'label'       => 'Search bar Text Color',
        'desc'        => 'Select a color.',
        'std'         => '#ffffff',
        'type'        => 'colorpicker',
        'section'     => 'style_content_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
      array(
        'id'          => 'style_bg_img',
        'label'       => 'Body Background options',
        'desc'        => '',
        'std'         => '',
        'type'        => 'background',
        'section'     => 'style_content_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
      array(
        'id'          => 'style_bg_img_100percent',
        'label'       => 'Full width background Image',
        'desc'        => '',
        'std'         => '',
        'type'        => 'checkbox',
        'section'     => 'style_content_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'choices'     => array( 
          array(
            'value'       => 'yes',
            'label'       => 'Enable 100% background cover',
            'src'         => ''
          )
        ),
      ),
      array(
        'id'          => 'style_content_option',
        'label'       => 'Content options',
        'desc'        => '',
        'std'         => '',
        'type'        => 'textblock-titled',
        'section'     => 'style_content_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
      array(
        'id'          => 'style_text_color',
        'label'       => 'Content Text Color',
        'desc'        => 'Select a color.',
        'std'         => '#ffffff',
        'type'        => 'colorpicker',
        'section'     => 'style_content_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
      array(
        'id'          => 'style_text_link_color',
        'label'       => 'Content Text Link Color',
        'desc'        => 'Select a color.',
        'std'         => '#ffffff',
        'type'        => 'colorpicker',
        'section'     => 'style_content_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
      array(
        'id'          => 'style_headers_color',
        'label'       => 'Content text heading Color',
        'desc'        => 'Select a color.',
        'std'         => '#000000',
        'type'        => 'colorpicker',
        'section'     => 'style_content_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
      array(
        'id'          => 'style_headers_link_color',
        'label'       => 'Content text heading Link Color',
        'desc'        => 'Select a color.',
        'std'         => '#000000',
        'type'        => 'colorpicker',
        'section'     => 'style_content_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
      array(
        'id'          => 'style_highlight_color',
        'label'       => 'Highlight Color',
        'desc'        => 'Date & Footer title color.',
        'std'         => '#ff5b01',
        'type'        => 'colorpicker',
        'section'     => 'style_content_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
      array(
        'id'          => 'style_button_text_color',
        'label'       => 'Button link Color',
        'desc'        => 'Select a color.',
        'std'         => '#ffffff',
        'type'        => 'colorpicker',
        'section'     => 'style_content_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
      array(
        'id'          => 'style_button_bg_top_color',
        'label'       => 'Button Hover gradient Top Color',
        'desc'        => 'Select a color.',
        'std'         => '#fca275',
        'type'        => 'colorpicker',
        'section'     => 'style_content_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
      array(
        'id'          => 'style_button_bg_bottom_color',
        'label'       => 'Button Hover gradient Bottom Color',
        'desc'        => 'Select a color.',
        'std'         => '#e94d00',
        'type'        => 'colorpicker',
        'section'     => 'style_content_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
      array(
        'id'          => 'style_weblinks_title_color',
        'label'       => 'Column Title Color',
        'desc'        => 'Select a color.',
        'std'         => '#000000',
        'type'        => 'colorpicker',
        'section'     => 'style_boxes_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
      array(
        'id'          => 'style_weblinks_bottom_border_color',
        'label'       => 'Column Bottom Border Color',
        'desc'        => 'Select a color.',
        'std'         => '#02779d',
        'type'        => 'colorpicker',
        'section'     => 'style_boxes_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
      array(
        'id'          => 'style_weblinks_bottom_border_shadow_color',
        'label'       => 'Column List Bottom Border Shadow Color',
        'desc'        => 'Select a color.',
        'std'         => '#013a4c',
        'type'        => 'colorpicker',
        'section'     => 'style_boxes_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
      array(
        'id'          => 'style_weblinks_icon_color',
        'label'       => 'Column list Icon Color',
        'desc'        => 'Select a color.',
        'std'         => '#ff5704',
        'type'        => 'colorpicker',
        'section'     => 'style_boxes_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
      array(
        'id'          => 'style_weblinks_bg_top_color',
        'label'       => 'Column list button Hover gradient Top Color',
        'desc'        => 'Select a color.',
        'std'         => '#ffffff',
        'type'        => 'colorpicker',
        'section'     => 'style_boxes_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
      array(
        'id'          => 'style_weblinks_bg_bottom_color',
        'label'       => 'Column list button Hover gradient Bottom Color',
        'desc'        => 'Select a color.',
        'std'         => '#cbcbcb',
        'type'        => 'colorpicker',
        'section'     => 'style_boxes_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
      array(
        'id'          => 'style_weblinks_link_color',
        'label'       => 'Column list Link Color',
        'desc'        => 'Select a color.',
        'std'         => '#ffffff',
        'type'        => 'colorpicker',
        'section'     => 'style_boxes_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
      array(
        'id'          => 'style_weblinks_link_hover_color',
        'label'       => 'Column list Hover Link Color',
        'desc'        => 'Select a color.',
        'std'         => '#000000',
        'type'        => 'colorpicker',
        'section'     => 'style_boxes_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
      array(
        'id'          => 'style_bg_box_color',
        'label'       => 'Column background Color',
        'desc'        => 'Select a color.',
        'std'         => '#ffffff',
        'type'        => 'colorpicker',
        'section'     => 'style_boxes_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
      array(
        'id'          => 'style_bg_box_transparent_level',
        'label'       => 'Column Transparent Level',
        'desc'        => 'Select a level.',
        'std'         => '0.2',
        'type'        => 'select',
        'section'     => 'style_boxes_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'choices'     => array( 
          array(
            'value'       => '0.1',
            'label'       => '0.1',
            'src'         => ''
          ),
          array(
            'value'       => '0.2',
            'label'       => '0.2',
            'src'         => ''
          ),
          array(
            'value'       => '0.3',
            'label'       => '0.3',
            'src'         => ''
          ),
          array(
            'value'       => '0.4',
            'label'       => '0.4',
            'src'         => ''
          ),
          array(
            'value'       => '0.5',
            'label'       => '0.5',
            'src'         => ''
          ),
          array(
            'value'       => '0.6',
            'label'       => '0.6',
            'src'         => ''
          ),
          array(
            'value'       => '0.7',
            'label'       => '0.7',
            'src'         => ''
          ),
          array(
            'value'       => '0.8',
            'label'       => '0.8',
            'src'         => ''
          ),
          array(
            'value'       => '0.9',
            'label'       => '0.9',
            'src'         => ''
          ),
          array(
            'value'       => '1.0',
            'label'       => '1.0',
            'src'         => ''
          ),
        ),
      ),
      array(
        'id'          => 'style_bg_box_boder_width',
        'label'       => 'Column Border Width',
        'desc'        => 'Select a width.',
        'std'         => '0',
        'type'        => 'select',
        'section'     => 'style_boxes_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'choices'     => array( 
          array(
            'value'       => '0',
            'label'       => '0',
            'src'         => ''
          ),
          array(
            'value'       => '1',
            'label'       => '1',
            'src'         => ''
          ),
          array(
            'value'       => '2',
            'label'       => '2',
            'src'         => ''
          ),
          array(
            'value'       => '3',
            'label'       => '3',
            'src'         => ''
          ),
          array(
            'value'       => '4',
            'label'       => '4',
            'src'         => ''
          ),
          array(
            'value'       => '5',
            'label'       => '5',
            'src'         => ''
          ),
        ),
      ),
      array(
        'id'          => 'style_bg_box_boder_style',
        'label'       => 'Column Border Style',
        'desc'        => 'Select a style.',
        'std'         => 'solid',
        'type'        => 'select',
        'section'     => 'style_boxes_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'choices'     => array( 
          array(
            'value'       => 'dotted',
            'label'       => 'dotted',
            'src'         => ''
          ),
          array(
            'value'       => 'dashed',
            'label'       => 'dashed',
            'src'         => ''
          ),
          array(
            'value'       => 'solid',
            'label'       => 'solid',
            'src'         => ''
          ),
          array(
            'value'       => 'double',
            'label'       => 'double',
            'src'         => ''
          ),
          array(
            'value'       => 'groove',
            'label'       => 'groove',
            'src'         => ''
          ),
          array(
            'value'       => 'ridge',
            'label'       => 'ridge',
            'src'         => ''
          ),
          array(
            'value'       => 'inset',
            'label'       => 'inset',
            'src'         => ''
          ),
          array(
            'value'       => 'outset',
            'label'       => 'outset',
            'src'         => ''
          ),
        ),
      ),
      array(
        'id'          => 'style_bg_box_boder_color',
        'label'       => 'Column Border Color',
        'desc'        => 'Select a color.',
        'std'         => '#000000',
        'type'        => 'colorpicker',
        'section'     => 'style_boxes_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
      array(
        'id'          => 'style_footer_bg_img',
        'label'       => 'Footer Background options',
        'desc'        => '',
        'std'         => '',
        'type'        => 'background',
        'section'     => 'style_footer_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
      array(
        'id'          => 'style_footer_bg_img_100percent',
        'label'       => 'Full width background Image',
        'desc'        => '',
        'std'         => '',
        'type'        => 'checkbox',
        'section'     => 'style_footer_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'choices'     => array( 
          array(
            'value'       => 'yes',
            'label'       => 'Enable 100% background cover',
            'src'         => ''
          )
        ),
      ),
      array(
        'id'          => 'style_footer_logo_pos',
        'label'       => 'Footer Logo position',
        'desc'        => '',
        'std'         => 'menu',
        'type'        => 'select',
        'section'     => 'style_footer_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'choices'     => array( 
          array(
            'value'       => 'menu',
            'label'       => 'Menu',
            'src'         => ''
          ),
          array(
            'value'       => 'footer',
            'label'       => 'Footer',
            'src'         => ''
          )
        ),
      ),
      array(
        'id'          => 'style_footer_logo_text_color',
        'label'       => 'Logo Title Color',
        'desc'        => 'Select a color.',
        'std'         => '#000000',
        'type'        => 'colorpicker',
        'section'     => 'style_footer_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
      array(
        'id'          => 'style_footer_logo_descr_color',
        'label'       => 'Logo Description Color',
        'desc'        => 'Select a color.',
        'std'         => '#ff5b01',
        'type'        => 'colorpicker',
        'section'     => 'style_footer_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
      array(
        'id'          => 'style_footer_logo_bg_top_color',
        'label'       => 'Logo Background Top Gradient Color ',
        'desc'        => 'Select a color.',
        'std'         => '#ffffff',
        'type'        => 'colorpicker',
        'section'     => 'style_footer_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
      array(
        'id'          => 'style_footer_logo_bg_bottom_color',
        'label'       => 'Logo Background Bottom Gradient Color',
        'desc'        => 'Select a color.',
        'std'         => '#ededed',
        'type'        => 'colorpicker',
        'section'     => 'style_footer_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
      array(
        'id'          => 'style_footer_text_color',
        'label'       => 'Text Color',
        'desc'        => 'Select a color.',
        'std'         => '#ffffff',
        'type'        => 'colorpicker',
        'section'     => 'style_footer_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
      array(
        'id'          => 'style_footer_link_color',
        'label'       => 'Link Color',
        'desc'        => 'Select a color.',
        'std'         => '#ffffff',
        'type'        => 'colorpicker',
        'section'     => 'style_footer_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
      array(
        'id'          => 'style_footer_link_hover_color',
        'label'       => 'Link Hover Color',
        'desc'        => 'Select a color.',
        'std'         => '#ffffff',
        'type'        => 'colorpicker',
        'section'     => 'style_footer_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
      array(
        'id'          => 'style_footer_menu_width',
        'label'       => 'Menu Width',
        'desc'        => '',
        'std'         => 'full',
        'type'        => 'radio',
        'section'     => 'style_footer_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'choices'     => array( 
          array(
            'value'       => 'full',
            'label'       => 'Full Width',
            'src'         => ''
          ),
          array(
            'value'       => 'fixed',
            'label'       => 'Fixed',
            'src'         => ''
          )
        ),
      ),
      array(
        'id'          => 'style_footer_menu_show',
        'label'       => 'Show Menu',
        'desc'        => 'Do you want to show menu?',
        'std'         => 'yes',
        'type'        => 'radio',
        'section'     => 'style_footer_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'choices'     => array( 
          array(
            'value'       => 'yes',
            'label'       => 'Yes',
            'src'         => ''
          ),
          array(
            'value'       => 'no',
            'label'       => 'No',
            'src'         => ''
          )
        ),
      ),
      array(
        'id'          => 'style_footer_shadow_show',
        'label'       => 'Show Menu Shadow',
        'desc'        => 'Do you want to show shadow?',
        'std'         => 'yes',
        'type'        => 'radio',
        'section'     => 'style_footer_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'choices'     => array( 
          array(
            'value'       => 'yes',
            'label'       => 'Yes',
            'src'         => ''
          ),
          array(
            'value'       => 'no',
            'label'       => 'No',
            'src'         => ''
          )
        ),
      ),
      array(
        'id'          => 'style_footer_menu_line_bg_top_color',
        'label'       => 'Footer Navigation bar  Background Top Gradient Color',
        'desc'        => 'Select a color.',
        'std'         => '#ffffff',
        'type'        => 'colorpicker',
        'section'     => 'style_footer_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
      array(
        'id'          => 'style_footer_menu_line_bg_bottom_color',
        'label'       => 'Footer Navigation bar Background Bottom gradient color',
        'desc'        => 'Select a color.',
        'std'         => '#ededed',
        'type'        => 'colorpicker',
        'section'     => 'style_footer_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
      array(
        'id'          => 'style_footer_menu_top_border_width',
        'label'       => 'Top Border Width',
        'desc'        => 'Select a width.',
        'std'         => '0',
        'type'        => 'select',
        'section'     => 'style_footer_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'choices'     => array( 
          array(
            'value'       => '0',
            'label'       => '0',
            'src'         => ''
          ),
          array(
            'value'       => '1',
            'label'       => '1',
            'src'         => ''
          ),
          array(
            'value'       => '2',
            'label'       => '2',
            'src'         => ''
          ),
          array(
            'value'       => '3',
            'label'       => '3',
            'src'         => ''
          ),
          array(
            'value'       => '4',
            'label'       => '4',
            'src'         => ''
          ),
          array(
            'value'       => '5',
            'label'       => '5',
            'src'         => ''
          ),
        ),
      ),
      array(
        'id'          => 'style_footer_menu_top_border_style',
        'label'       => 'Top Border Style',
        'desc'        => 'Select a style.',
        'std'         => 'solid',
        'type'        => 'select',
        'section'     => 'style_footer_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'choices'     => array( 
          array(
            'value'       => 'dotted',
            'label'       => 'dotted',
            'src'         => ''
          ),
          array(
            'value'       => 'dashed',
            'label'       => 'dashed',
            'src'         => ''
          ),
          array(
            'value'       => 'solid',
            'label'       => 'solid',
            'src'         => ''
          ),
          array(
            'value'       => 'double',
            'label'       => 'double',
            'src'         => ''
          ),
          array(
            'value'       => 'groove',
            'label'       => 'groove',
            'src'         => ''
          ),
          array(
            'value'       => 'ridge',
            'label'       => 'ridge',
            'src'         => ''
          ),
          array(
            'value'       => 'inset',
            'label'       => 'inset',
            'src'         => ''
          ),
          array(
            'value'       => 'outset',
            'label'       => 'outset',
            'src'         => ''
          ),
        ),
      ),
      array(
        'id'          => 'style_footer_menu_top_border_color',
        'label'       => 'Top Border Color',
        'desc'        => 'Select a color.',
        'std'         => '#000000',
        'type'        => 'colorpicker',
        'section'     => 'style_footer_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
      array(
        'id'          => 'style_footer_menu_bottom_border_width',
        'label'       => 'Bottom Border Width',
        'desc'        => 'Select a width.',
        'std'         => '0',
        'type'        => 'select',
        'section'     => 'style_footer_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'choices'     => array( 
          array(
            'value'       => '0',
            'label'       => '0',
            'src'         => ''
          ),
          array(
            'value'       => '1',
            'label'       => '1',
            'src'         => ''
          ),
          array(
            'value'       => '2',
            'label'       => '2',
            'src'         => ''
          ),
          array(
            'value'       => '3',
            'label'       => '3',
            'src'         => ''
          ),
          array(
            'value'       => '4',
            'label'       => '4',
            'src'         => ''
          ),
          array(
            'value'       => '5',
            'label'       => '5',
            'src'         => ''
          ),
        ),
      ),
      array(
        'id'          => 'style_footer_menu_bottom_border_style',
        'label'       => 'Bottom Border Style',
        'desc'        => 'Select a style.',
        'std'         => 'solid',
        'type'        => 'select',
        'section'     => 'style_footer_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'choices'     => array( 
          array(
            'value'       => 'dotted',
            'label'       => 'dotted',
            'src'         => ''
          ),
          array(
            'value'       => 'dashed',
            'label'       => 'dashed',
            'src'         => ''
          ),
          array(
            'value'       => 'solid',
            'label'       => 'solid',
            'src'         => ''
          ),
          array(
            'value'       => 'double',
            'label'       => 'double',
            'src'         => ''
          ),
          array(
            'value'       => 'groove',
            'label'       => 'groove',
            'src'         => ''
          ),
          array(
            'value'       => 'ridge',
            'label'       => 'ridge',
            'src'         => ''
          ),
          array(
            'value'       => 'inset',
            'label'       => 'inset',
            'src'         => ''
          ),
          array(
            'value'       => 'outset',
            'label'       => 'outset',
            'src'         => ''
          ),
        ),
      ),
      array(
        'id'          => 'style_footer_menu_bottom_border_color',
        'label'       => 'Bottom Border Color',
        'desc'        => 'Select a color.',
        'std'         => '#000000',
        'type'        => 'colorpicker',
        'section'     => 'style_footer_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
      array(
        'id'          => 'style_footer_menu_bg',
        'label'       => 'Footer navigation Background options',
        'desc'        => '',
        'std'         => '',
        'type'        => 'background',
        'section'     => 'style_footer_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
      array(
        'id'          => 'style_footer_menu_100percent',
        'label'       => 'Menu Full width background Image',
        'desc'        => '',
        'std'         => '',
        'type'        => 'checkbox',
        'section'     => 'style_footer_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'choices'     => array( 
          array(
            'value'       => 'yes',
            'label'       => 'Enable 100% background cover',
            'src'         => ''
          )
        ),
      ),
      array(
        'id'          => 'social_icon_color',
        'label'       => 'Icon Color',
        'desc'        => 'Select a color.',
        'std'         => '#000000',
        'type'        => 'colorpicker',
        'section'     => 'social_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
      array(
        'id'          => 'social_icon_hover_color',
        'label'       => 'Icon Hover Color',
        'desc'        => 'Select a color.',
        'std'         => '#ff5b01',
        'type'        => 'colorpicker',
        'section'     => 'social_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
      array(
        'id'          => 'social_facebook_url',
        'label'       => 'Facebook URL',
        'desc'        => '',
        'std'         => '',
        'type'        => 'text',
        'section'     => 'social_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
      array(
        'id'          => 'social_twitter_url',
        'label'       => 'Twitter URL',
        'desc'        => '',
        'std'         => '',
        'type'        => 'text',
        'section'     => 'social_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
      array(
        'id'          => 'social_google_plus_url',
        'label'       => 'Google Plus URL',
        'desc'        => '',
        'std'         => '',
        'type'        => 'text',
        'section'     => 'social_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
      array(
        'id'          => 'social_youtube_url',
        'label'       => 'Youtube URL',
        'desc'        => '',
        'std'         => '',
        'type'        => 'text',
        'section'     => 'social_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
      array(
        'id'          => 'social_vimeo_url',
        'label'       => 'Vimeo URL',
        'desc'        => '',
        'std'         => '',
        'type'        => 'text',
        'section'     => 'social_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
      array(
        'id'          => 'social_linkedin_url',
        'label'       => 'LinkedIn URL',
        'desc'        => '',
        'std'         => '',
        'type'        => 'text',
        'section'     => 'social_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
      array(
        'id'          => 'social_pinterest_url',
        'label'       => 'Pinterest URL',
        'desc'        => '',
        'std'         => '',
        'type'        => 'text',
        'section'     => 'social_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
      array(
        'id'          => 'social_flickr_url',
        'label'       => 'Flickr URL',
        'desc'        => '',
        'std'         => '',
        'type'        => 'text',
        'section'     => 'social_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
      array(
        'id'          => 'social_rss_url',
        'label'       => 'RSS URL',
        'desc'        => '',
        'std'         => get_bloginfo('rss2_url'),
        'type'        => 'text',
        'section'     => 'social_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => ''
      ),
      array(
        'id'          => 'fonts_text',
        'label'       => 'Content Text',
        'desc'        => '',
        'std'         => '',
        'type'        => 'select',
        'section'     => 'fonts_settings_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'choices'     => am_prepare_fonts(),
      ),
      array(
        'id'          => 'fonts_text_titles',
        'label'       => 'Content Titles',
        'desc'        => '',
        'std'         => '',
        'type'        => 'select',
        'section'     => 'fonts_settings_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'choices'     => am_prepare_fonts(),
      ),
      array(
        'id'          => 'fonts_menu_links',
        'label'       => 'Navigation Links',
        'desc'        => '',
        'std'         => '',
        'type'        => 'select',
        'section'     => 'fonts_settings_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'choices'     => am_prepare_fonts(),
      ),
      array(
        'id'          => 'fonts_box_text',
        'label'       => 'Column Text',
        'desc'        => '',
        'std'         => '',
        'type'        => 'select',
        'section'     => 'fonts_settings_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'choices'     => am_prepare_fonts(),
      ),
      array(
        'id'          => 'fonts_box_titles',
        'label'       => 'Column Titles',
        'desc'        => '',
        'std'         => '',
        'type'        => 'select',
        'section'     => 'fonts_settings_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'choices'     => am_prepare_fonts(),
      ),
      array(
        'id'          => 'fonts_logo',
        'label'       => 'Logo',
        'desc'        => '',
        'std'         => '',
        'type'        => 'select',
        'section'     => 'fonts_settings_section',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'class'       => '',
        'choices'     => am_prepare_fonts(),
      ),
    )
  );
  
  /* allow settings to be filtered before saving */
  $custom_settings = apply_filters( 'option_tree_settings_args', $custom_settings );
  
  /* settings are not the same update the DB */
  if ( $saved_settings !== $custom_settings ) {
    update_option( 'option_tree_settings', $custom_settings ); 
  }
  
}